==> haskell-js-jquery-3.7.1-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-jquery
version:              3.7.1
visibility:           public
id:                   js-jquery-3.7.1-9PJMhvYklo2JmMe9sf0BMd
key:                  js-jquery-3.7.1-9PJMhvYklo2JmMe9sf0BMd
license:              MIT
copyright:            Neil Mitchell 2014-2025
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-jquery#readme
synopsis:             Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  e4bbca10fe6ad68c752d3a838e1c6e30
exposed:              True
exposed-modules:      Language.Javascript.JQuery
hidden-modules:       Paths_js_jquery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/js-jquery-3.7.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/js-jquery-3.7.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/js-jquery-3.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-jquery
hs-libraries:         HSjs-jquery-3.7.1-9PJMhvYklo2JmMe9sf0BMd
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html:         /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-jquery-3.7.1-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-jquery
version:              3.7.1
visibility:           public
id:                   js-jquery-3.7.1-E5NVMN7mmfkGQCIpd69LlP
key:                  js-jquery-3.7.1-E5NVMN7mmfkGQCIpd69LlP
license:              MIT
copyright:            Neil Mitchell 2014-2025
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-jquery#readme
synopsis:             Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  d5eddc6804106e688bfbc1865edd4ae1
exposed:              True
exposed-modules:      Language.Javascript.JQuery
hidden-modules:       Paths_js_jquery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/js-jquery-3.7.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/js-jquery-3.7.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/js-jquery-3.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-jquery
hs-libraries:         HSjs-jquery-3.7.1-E5NVMN7mmfkGQCIpd69LlP
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html:         /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
